==> nzbget-0.2.2.tar.gz: nzbget-0.2.2/NewsServer.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.5 $
 * $Date: 2005/07/13 15:06:03 $
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string.h>
#include <stdlib.h>

#include "NewsServer.h"
#include "global.h"

NewsServer::NewsServer(char* host, int port, char* user, char* pass) : NetAddress(host,port)
{
	m_szUser = NULL;
	SetUser(user);
	m_szPassword = NULL;
	SetPassword(pass);
}

NewsServer::~NewsServer()
{
	free( m_szUser );
	m_szUser = NULL;
	free( m_szPassword );
	m_szPassword = NULL;
}

void NewsServer::SetUser(char* v)
{
	if (m_szUser)
	{
		free(m_szUser);
	}
	
	if (v)
	{
		m_szUser = strdup(v);
	}
	else
	{
		m_szUser = v;
	}
}

char* NewsServer::GetUser()
{
	return m_szUser;
}

void NewsServer::SetPassword(char* v)
{
	if (m_szPassword)
	{
		free(m_szPassword);
	}
	
	if (v)
	{
		m_szPassword = strdup(v);
	}
	else
	{
		m_szPassword = v;
	}
}

char* NewsServer::GetPassword()
{
	return m_szPassword;
}

==> nzbget-0.4.0.tar.gz: nzbget-0.4.0/NewsServer.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *  Copyright (C) 2007  Andrei Prygounkov <hugbug@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 10 $
 * $Date: 2007-12-08 14:51:54 +0100 (Sat, 08 Dec 2007) $
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef WIN32
#include "win32.h"
#endif

#include <stdlib.h>
#include <string.h>

#include "nzbget.h"
#include "NewsServer.h"
#include "Log.h"

NewsServer::NewsServer(const char* host, int port, const char* user, const char* pass, int maxConnections, int level) : NetAddress(host, port)
{
	m_szUser = NULL;
	m_szPassword = NULL;
	m_iLevel = level;
	m_iMaxConnections = maxConnections;

	if (pass)
	{
		m_szPassword = strdup(pass);
	}
	if (user)
	{
		m_szUser = strdup(user);
	}
}

NewsServer::~NewsServer()
{
	free(m_szUser);
	m_szUser = NULL;
	free(m_szPassword);
	m_szPassword = NULL;
}
